# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: users.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from . import peers_pb2 as peers__pb2
from . import media_and_files_pb2 as media__and__files__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='users.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0busers.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x13miscellaneous.proto\x1a\x0bpeers.proto\x1a\x15media_and_files.proto\x1a\x15scalapb/scalapb.proto\"\xfd\x02\n\rContactRecord\x12\x30\n\x04type\x18\x01 \x01(\x0e\x32\x13.dialog.ContactTypeB\r\x8a\xea\x30\t\n\x07visible\x12=\n\ttype_spec\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x41\n\x0cstring_value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12>\n\nlong_value\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\r\x8a\xea\x30\t\n\x07visible\x12:\n\x05title\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12<\n\x08subtitle\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\"\x9a\x01\n\nUserStatus\x12\x33\n\x04type\x18\x01 \x01(\x0e\x32\x16.dialog.UserStatusTypeB\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x04text\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05\x63lock\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"\xf6\x07\n\x08UserData\x12\x1a\n\x04name\x18\x01 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x39\n\x04nick\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12&\n\x03sex\x18\x03 \x01(\x0e\x32\x0b.dialog.SexB\x0c\x8a\xea\x30\x08\n\x06hidden\x12-\n\x06\x61vatar\x18\x04 \x01(\x0b\x32\x0e.dialog.AvatarB\r\x8a\xea\x30\t\n\x07\x63ompact\x12\x39\n\x06is_bot\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x06status\x18\x06 \x01(\x0e\x32\x1a.dialog.UserData.LifecycleB\r\x8a\xea\x30\t\n\x07visible\x12\x36\n\x0buser_status\x18\x07 \x01(\x0b\x32\x12.dialog.UserStatusB\r\x8a\xea\x30\t\n\x07visible\x12 \n\ttime_zone\x18\x08 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x30\n\x04\x65xts\x18\t \x03(\x0b\x32\x14.dialog.UserData.ExtB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x37\n\robsoleteClock\x18\n \x01(\x0b\x32\x11.dialog.DataClockB\r\x8a\xea\x30\t\n\x07visible\x12\x0f\n\x07locales\x18\x0b \x03(\t\x12:\n\x05\x61\x62out\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07\x63ompact\x12:\n\x0c\x63ontact_info\x18\r \x03(\x0b\x32\x15.dialog.ContactRecordB\r\x8a\xea\x30\t\n\x07\x63ompact\x12\x37\n\x0c\x62ot_commands\x18\x0e \x03(\x0b\x32\x12.dialog.BotCommandB\r\x8a\xea\x30\t\n\x07visible\x12\x34\n\x0e\x63ustom_profile\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12#\n\x04hint\x18\x11 \x01(\x0e\x32\x15.dialog.UserData.Hint\x12\x16\n\x0ewas_authorized\x18\x12 \x01(\x08\x12\r\n\x05\x63lock\x18\x10 \x01(\x03\x1a\x31\n\x03\x45xt\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0b\n\x01s\x18\x02 \x01(\tH\x00\x12\x0b\n\x01\x62\x18\x03 \x01(\x08H\x00\x42\x03\n\x01v\"V\n\tLifecycle\x12\n\n\x06MISSED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0b\n\x07\x44\x45LETED\x10\x02\x12\x0b\n\x07\x42LOCKED\x10\x03\x12\x17\n\x13\x42LOCKED_AND_DELETED\x10\x04\"2\n\x04Hint\x12\x15\n\x11user_hint_regular\x10\x00\x12\x13\n\x0fuser_hint_guest\x10\x01\"d\n\x04User\x12\x19\n\x02id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12!\n\x0b\x61\x63\x63\x65ss_hash\x18\x02 \x01(\x03\x42\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\x12\x1e\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x10.dialog.UserData\"\xf4\x01\n\x0fUserPartialInfo\x12\x19\n\x02id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12!\n\x0b\x61\x63\x63\x65ss_hash\x18\x02 \x01(\x03\x42\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\x12\x1c\n\x05\x63lock\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04name\x18\x04 \x01(\tB\r\x8a\xea\x30\t\n\x07\x63ompact\x12\x39\n\x04nick\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12-\n\x06\x61vatar\x18\x06 \x01(\x0b\x32\x0e.dialog.AvatarB\r\x8a\xea\x30\t\n\x07\x63ompact\"\xa5\x03\n\x0bUserProfile\x12)\n\x04user\x18\x01 \x01(\x0b\x32\x0c.dialog.UserB\r\x8a\xea\x30\t\n\x07visible\x12:\n\x0c\x63ontact_info\x18\x02 \x03(\x0b\x32\x15.dialog.ContactRecordB\r\x8a\xea\x30\t\n\x07\x63ompact\x12\x39\n\x05\x61\x62out\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12*\n\x13preferred_languages\x18\x04 \x03(\tB\r\x8a\xea\x30\t\n\x07visible\x12>\n\ttime_zone\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12\x37\n\x0c\x62ot_commands\x18\x06 \x03(\x0b\x32\x12.dialog.BotCommandB\r\x8a\xea\x30\t\n\x07visible\x12\x16\n\x0e\x63ustom_profile\x18\t \x01(\t\x12\x37\n\x11integration_token\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x84\x04\n\x08\x46ullUser\x12\x19\n\x02id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12:\n\x0c\x63ontact_info\x18\x02 \x03(\x0b\x32\x15.dialog.ContactRecordB\r\x8a\xea\x30\t\n\x07\x63ompact\x12\x39\n\x05\x61\x62out\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12*\n\x13preferred_languages\x18\x04 \x03(\tB\r\x8a\xea\x30\t\n\x07visible\x12>\n\ttime_zone\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12\x37\n\x0c\x62ot_commands\x18\x06 \x03(\x0b\x32\x12.dialog.BotCommandB\r\x8a\xea\x30\t\n\x07visible\x12=\n\nis_blocked\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12\x16\n\x0e\x63ustom_profile\x18\t \x01(\t\x12\x37\n\x11integration_token\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x06status\x18\x0b \x01(\x0b\x32\x12.dialog.UserStatusB\r\x8a\xea\x30\t\n\x07visible\"\x94\x01\n\nBotCommand\x12$\n\rslash_command\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\"\n\x0b\x64\x65scription\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12<\n\x07loc_key\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\"\x93\x01\n\x18RequestEditUserLocalName\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12!\n\x0b\x61\x63\x63\x65ss_hash\x18\x02 \x01(\x03\x42\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\x12\x1a\n\x04name\x18\x03 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xac\x02\n\x13RequestLoadUserData\x12@\n\x06\x63laims\x18\x01 \x03(\x0b\x32!.dialog.RequestLoadUserData.ClaimB\r\x8a\xea\x30\t\n\x07visible\x1a\xb4\x01\n\x05\x43laim\x12.\n\tuser_peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x03p2p\x18\x02 \x01(\x08\x42\r\x8a\xea\x30\t\n\x07visibleH\x00\x12\x33\n\x0cgroup_member\x18\x03 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visibleH\x00\x12 \n\x07\x63ontact\x18\x04 \x01(\x08\x42\r\x8a\xea\x30\t\n\x07visibleH\x00\x42\x06\n\x04kind:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"a\n\x14ResponseLoadUserData\x12*\n\x05users\x18\x01 \x03(\x0b\x32\x0c.dialog.UserB\r\x8a\xea\x30\t\n\x07visible:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"8\n\nUpdateUser\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x1e\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x10.dialog.UserData\"d\n\x17UpdateUserAvatarChanged\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12-\n\x06\x61vatar\x18\x02 \x01(\x0b\x32\x0e.dialog.AvatarB\r\x8a\xea\x30\t\n\x07\x63ompact\"O\n\x15UpdateUserNameChanged\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x04name\x18\x02 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\"x\n\x1aUpdateUserLocalNameChanged\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12>\n\nlocal_name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\"v\n\x19UpdateUserContactsChanged\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12=\n\x0f\x63ontact_records\x18\x04 \x03(\x0b\x32\x15.dialog.ContactRecordB\r\x8a\xea\x30\t\n\x07\x63ompact\"r\n\x15UpdateUserNickChanged\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12=\n\x08nickname\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\"o\n\x16UpdateUserAboutChanged\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x39\n\x05\x61\x62out\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\"m\n#UpdateUserPreferredLanguagesChanged\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12*\n\x13preferred_languages\x18\x02 \x03(\tB\r\x8a\xea\x30\t\n\x07visible\"w\n\x19UpdateUserTimeZoneChanged\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12>\n\ttime_zone\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\"o\n\x1cUpdateUserBotCommandsChanged\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x33\n\x08\x63ommands\x18\x02 \x03(\x0b\x32\x12.dialog.BotCommandB\r\x8a\xea\x30\t\n\x07visible\"Z\n\x14UpdateUserSexChanged\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12&\n\x03sex\x18\x02 \x01(\x0e\x32\x0b.dialog.SexB\x0c\x8a\xea\x30\x08\n\x06hidden\"c\n\x1eUpdateUserCustomProfileChanged\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12%\n\x0e\x63ustom_profile\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\"h\n\x17UpdateUserStatusChanged\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x31\n\x06status\x18\x02 \x01(\x0b\x32\x12.dialog.UserStatusB\r\x8a\xea\x30\t\n\x07visible\"i\n\x14UpdateUserExtChanged\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x35\n\x03\x65xt\x18\x02 \x01(\x0b\x32\x19.dialog.RecursiveMapValueB\r\x8a\xea\x30\t\n\x07visible\"m\n\x18UpdateUserFullExtChanged\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x35\n\x03\x65xt\x18\x02 \x01(\x0b\x32\x19.dialog.RecursiveMapValueB\r\x8a\xea\x30\t\n\x07visible\"l\n\x14RequestLoadFullUsers\x12\x36\n\nuser_peers\x18\x01 \x03(\x0b\x32\x13.dialog.UserOutPeerB\r\x8a\xea\x30\t\n\x07\x63ompact:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\\\n\x15ResponseLoadFullUsers\x12$\n\nfull_users\x18\x01 \x03(\x0b\x32\x10.dialog.FullUser:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse*4\n\x03Sex\x12\x0f\n\x0bSEX_UNKNOWN\x10\x00\x12\x0c\n\x08SEX_MALE\x10\x02\x12\x0e\n\nSEX_FEMALE\x10\x03*\x81\x01\n\x0b\x43ontactType\x12\x17\n\x13\x43ONTACTTYPE_UNKNOWN\x10\x00\x12\x15\n\x11\x43ONTACTTYPE_PHONE\x10\x01\x12\x15\n\x11\x43ONTACTTYPE_EMAIL\x10\x02\x12\x13\n\x0f\x43ONTACTTYPE_WEB\x10\x03\x12\x16\n\x12\x43ONTACTTYPE_SOCIAL\x10\x04*\xb7\x01\n\x0eUserStatusType\x12\x1a\n\x16USERSTATUSTYPE_UNKNOWN\x10\x00\x12\x18\n\x14USERSTATUSTYPE_UNSET\x10\x01\x12\x17\n\x13USERSTATUSTYPE_AWAY\x10\x02\x12\x1f\n\x1bUSERSTATUSTYPE_DONOTDISTURB\x10\x03\x12\x1c\n\x18USERSTATUSTYPE_INVISIBLE\x10\x04\x12\x17\n\x13USERSTATUSTYPE_BUSY\x10\x05\x32\xea\x02\n\x05Users\x12w\n\x11\x45\x64itUserLocalName\x12 .dialog.RequestEditUserLocalName\x1a\x13.dialog.ResponseSeq\"+\x82\xd3\xe4\x93\x02%\" /v1/grpc/Users/EditUserLocalName:\x01*\x12u\n\rLoadFullUsers\x12\x1c.dialog.RequestLoadFullUsers\x1a\x1d.dialog.ResponseLoadFullUsers\"\'\x82\xd3\xe4\x93\x02!\"\x1c/v1/grpc/Users/LoadFullUsers:\x01*\x12q\n\x0cLoadUserData\x12\x1b.dialog.RequestLoadUserData\x1a\x1c.dialog.ResponseLoadUserData\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/grpc/Users/LoadUserData:\x01*B\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,miscellaneous__pb2.DESCRIPTOR,peers__pb2.DESCRIPTOR,media__and__files__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])

_SEX = _descriptor.EnumDescriptor(
  name='Sex',
  full_name='dialog.Sex',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SEX_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEX_MALE', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEX_FEMALE', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5515,
  serialized_end=5567,
)
_sym_db.RegisterEnumDescriptor(_SEX)

Sex = enum_type_wrapper.EnumTypeWrapper(_SEX)
_CONTACTTYPE = _descriptor.EnumDescriptor(
  name='ContactType',
  full_name='dialog.ContactType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONTACTTYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTACTTYPE_PHONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTACTTYPE_EMAIL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTACTTYPE_WEB', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTACTTYPE_SOCIAL', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5570,
  serialized_end=5699,
)
_sym_db.RegisterEnumDescriptor(_CONTACTTYPE)

ContactType = enum_type_wrapper.EnumTypeWrapper(_CONTACTTYPE)
_USERSTATUSTYPE = _descriptor.EnumDescriptor(
  name='UserStatusType',
  full_name='dialog.UserStatusType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='USERSTATUSTYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='USERSTATUSTYPE_UNSET', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='USERSTATUSTYPE_AWAY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='USERSTATUSTYPE_DONOTDISTURB', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='USERSTATUSTYPE_INVISIBLE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='USERSTATUSTYPE_BUSY', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5702,
  serialized_end=5885,
)
_sym_db.RegisterEnumDescriptor(_USERSTATUSTYPE)

UserStatusType = enum_type_wrapper.EnumTypeWrapper(_USERSTATUSTYPE)
SEX_UNKNOWN = 0
SEX_MALE = 2
SEX_FEMALE = 3
CONTACTTYPE_UNKNOWN = 0
CONTACTTYPE_PHONE = 1
CONTACTTYPE_EMAIL = 2
CONTACTTYPE_WEB = 3
CONTACTTYPE_SOCIAL = 4
USERSTATUSTYPE_UNKNOWN = 0
USERSTATUSTYPE_UNSET = 1
USERSTATUSTYPE_AWAY = 2
USERSTATUSTYPE_DONOTDISTURB = 3
USERSTATUSTYPE_INVISIBLE = 4
USERSTATUSTYPE_BUSY = 5


_USERDATA_LIFECYCLE = _descriptor.EnumDescriptor(
  name='Lifecycle',
  full_name='dialog.UserData.Lifecycle',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MISSED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLOCKED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLOCKED_AND_DELETED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1602,
  serialized_end=1688,
)
_sym_db.RegisterEnumDescriptor(_USERDATA_LIFECYCLE)

_USERDATA_HINT = _descriptor.EnumDescriptor(
  name='Hint',
  full_name='dialog.UserData.Hint',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='user_hint_regular', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='user_hint_guest', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1690,
  serialized_end=1740,
)
_sym_db.RegisterEnumDescriptor(_USERDATA_HINT)


_CONTACTRECORD = _descriptor.Descriptor(
  name='ContactRecord',
  full_name='dialog.ContactRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='dialog.ContactRecord.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_spec', full_name='dialog.ContactRecord.type_spec', index=1,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='dialog.ContactRecord.string_value', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='long_value', full_name='dialog.ContactRecord.long_value', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.ContactRecord.title', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subtitle', full_name='dialog.ContactRecord.subtitle', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=185,
  serialized_end=566,
)


_USERSTATUS = _descriptor.Descriptor(
  name='UserStatus',
  full_name='dialog.UserStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='dialog.UserStatus.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='dialog.UserStatus.text', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.UserStatus.clock', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=569,
  serialized_end=723,
)


_USERDATA_EXT = _descriptor.Descriptor(
  name='Ext',
  full_name='dialog.UserData.Ext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dialog.UserData.Ext.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s', full_name='dialog.UserData.Ext.s', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b', full_name='dialog.UserData.Ext.b', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='v', full_name='dialog.UserData.Ext.v',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1551,
  serialized_end=1600,
)

_USERDATA = _descriptor.Descriptor(
  name='UserData',
  full_name='dialog.UserData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='dialog.UserData.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nick', full_name='dialog.UserData.nick', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sex', full_name='dialog.UserData.sex', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar', full_name='dialog.UserData.avatar', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_bot', full_name='dialog.UserData.is_bot', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='dialog.UserData.status', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_status', full_name='dialog.UserData.user_status', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='dialog.UserData.time_zone', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exts', full_name='dialog.UserData.exts', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obsoleteClock', full_name='dialog.UserData.obsoleteClock', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locales', full_name='dialog.UserData.locales', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='about', full_name='dialog.UserData.about', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contact_info', full_name='dialog.UserData.contact_info', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bot_commands', full_name='dialog.UserData.bot_commands', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_profile', full_name='dialog.UserData.custom_profile', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hint', full_name='dialog.UserData.hint', index=15,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='was_authorized', full_name='dialog.UserData.was_authorized', index=16,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.UserData.clock', index=17,
      number=16, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_USERDATA_EXT, ],
  enum_types=[
    _USERDATA_LIFECYCLE,
    _USERDATA_HINT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=726,
  serialized_end=1740,
)


_USER = _descriptor.Descriptor(
  name='User',
  full_name='dialog.User',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.User.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_hash', full_name='dialog.User.access_hash', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006danger', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='dialog.User.data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1742,
  serialized_end=1842,
)


_USERPARTIALINFO = _descriptor.Descriptor(
  name='UserPartialInfo',
  full_name='dialog.UserPartialInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.UserPartialInfo.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_hash', full_name='dialog.UserPartialInfo.access_hash', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006danger', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.UserPartialInfo.clock', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='dialog.UserPartialInfo.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nick', full_name='dialog.UserPartialInfo.nick', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar', full_name='dialog.UserPartialInfo.avatar', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1845,
  serialized_end=2089,
)


_USERPROFILE = _descriptor.Descriptor(
  name='UserProfile',
  full_name='dialog.UserProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='dialog.UserProfile.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contact_info', full_name='dialog.UserProfile.contact_info', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='about', full_name='dialog.UserProfile.about', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferred_languages', full_name='dialog.UserProfile.preferred_languages', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='dialog.UserProfile.time_zone', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bot_commands', full_name='dialog.UserProfile.bot_commands', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_profile', full_name='dialog.UserProfile.custom_profile', index=6,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='integration_token', full_name='dialog.UserProfile.integration_token', index=7,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2092,
  serialized_end=2513,
)


_FULLUSER = _descriptor.Descriptor(
  name='FullUser',
  full_name='dialog.FullUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.FullUser.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contact_info', full_name='dialog.FullUser.contact_info', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='about', full_name='dialog.FullUser.about', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferred_languages', full_name='dialog.FullUser.preferred_languages', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='dialog.FullUser.time_zone', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bot_commands', full_name='dialog.FullUser.bot_commands', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_blocked', full_name='dialog.FullUser.is_blocked', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_profile', full_name='dialog.FullUser.custom_profile', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='integration_token', full_name='dialog.FullUser.integration_token', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='dialog.FullUser.status', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2516,
  serialized_end=3032,
)


_BOTCOMMAND = _descriptor.Descriptor(
  name='BotCommand',
  full_name='dialog.BotCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='slash_command', full_name='dialog.BotCommand.slash_command', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='dialog.BotCommand.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loc_key', full_name='dialog.BotCommand.loc_key', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3035,
  serialized_end=3183,
)


_REQUESTEDITUSERLOCALNAME = _descriptor.Descriptor(
  name='RequestEditUserLocalName',
  full_name='dialog.RequestEditUserLocalName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.RequestEditUserLocalName.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_hash', full_name='dialog.RequestEditUserLocalName.access_hash', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006danger', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='dialog.RequestEditUserLocalName.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3186,
  serialized_end=3333,
)


_REQUESTLOADUSERDATA_CLAIM = _descriptor.Descriptor(
  name='Claim',
  full_name='dialog.RequestLoadUserData.Claim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_peer', full_name='dialog.RequestLoadUserData.Claim.user_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p2p', full_name='dialog.RequestLoadUserData.Claim.p2p', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_member', full_name='dialog.RequestLoadUserData.Claim.group_member', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contact', full_name='dialog.RequestLoadUserData.Claim.contact', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='dialog.RequestLoadUserData.Claim.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3426,
  serialized_end=3606,
)

_REQUESTLOADUSERDATA = _descriptor.Descriptor(
  name='RequestLoadUserData',
  full_name='dialog.RequestLoadUserData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='claims', full_name='dialog.RequestLoadUserData.claims', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_REQUESTLOADUSERDATA_CLAIM, ],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3336,
  serialized_end=3636,
)


_RESPONSELOADUSERDATA = _descriptor.Descriptor(
  name='ResponseLoadUserData',
  full_name='dialog.ResponseLoadUserData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.ResponseLoadUserData.users', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3638,
  serialized_end=3735,
)


_UPDATEUSER = _descriptor.Descriptor(
  name='UpdateUser',
  full_name='dialog.UpdateUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.UpdateUser.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='dialog.UpdateUser.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3737,
  serialized_end=3793,
)


_UPDATEUSERAVATARCHANGED = _descriptor.Descriptor(
  name='UpdateUserAvatarChanged',
  full_name='dialog.UpdateUserAvatarChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateUserAvatarChanged.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar', full_name='dialog.UpdateUserAvatarChanged.avatar', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3795,
  serialized_end=3895,
)


_UPDATEUSERNAMECHANGED = _descriptor.Descriptor(
  name='UpdateUserNameChanged',
  full_name='dialog.UpdateUserNameChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateUserNameChanged.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='dialog.UpdateUserNameChanged.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3897,
  serialized_end=3976,
)


_UPDATEUSERLOCALNAMECHANGED = _descriptor.Descriptor(
  name='UpdateUserLocalNameChanged',
  full_name='dialog.UpdateUserLocalNameChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateUserLocalNameChanged.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_name', full_name='dialog.UpdateUserLocalNameChanged.local_name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3978,
  serialized_end=4098,
)


_UPDATEUSERCONTACTSCHANGED = _descriptor.Descriptor(
  name='UpdateUserContactsChanged',
  full_name='dialog.UpdateUserContactsChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateUserContactsChanged.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contact_records', full_name='dialog.UpdateUserContactsChanged.contact_records', index=1,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4100,
  serialized_end=4218,
)


_UPDATEUSERNICKCHANGED = _descriptor.Descriptor(
  name='UpdateUserNickChanged',
  full_name='dialog.UpdateUserNickChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateUserNickChanged.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nickname', full_name='dialog.UpdateUserNickChanged.nickname', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4220,
  serialized_end=4334,
)


_UPDATEUSERABOUTCHANGED = _descriptor.Descriptor(
  name='UpdateUserAboutChanged',
  full_name='dialog.UpdateUserAboutChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateUserAboutChanged.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='about', full_name='dialog.UpdateUserAboutChanged.about', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4336,
  serialized_end=4447,
)


_UPDATEUSERPREFERREDLANGUAGESCHANGED = _descriptor.Descriptor(
  name='UpdateUserPreferredLanguagesChanged',
  full_name='dialog.UpdateUserPreferredLanguagesChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateUserPreferredLanguagesChanged.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferred_languages', full_name='dialog.UpdateUserPreferredLanguagesChanged.preferred_languages', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4449,
  serialized_end=4558,
)


_UPDATEUSERTIMEZONECHANGED = _descriptor.Descriptor(
  name='UpdateUserTimeZoneChanged',
  full_name='dialog.UpdateUserTimeZoneChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateUserTimeZoneChanged.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='dialog.UpdateUserTimeZoneChanged.time_zone', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4560,
  serialized_end=4679,
)


_UPDATEUSERBOTCOMMANDSCHANGED = _descriptor.Descriptor(
  name='UpdateUserBotCommandsChanged',
  full_name='dialog.UpdateUserBotCommandsChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateUserBotCommandsChanged.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commands', full_name='dialog.UpdateUserBotCommandsChanged.commands', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4681,
  serialized_end=4792,
)


_UPDATEUSERSEXCHANGED = _descriptor.Descriptor(
  name='UpdateUserSexChanged',
  full_name='dialog.UpdateUserSexChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateUserSexChanged.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sex', full_name='dialog.UpdateUserSexChanged.sex', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4794,
  serialized_end=4884,
)


_UPDATEUSERCUSTOMPROFILECHANGED = _descriptor.Descriptor(
  name='UpdateUserCustomProfileChanged',
  full_name='dialog.UpdateUserCustomProfileChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateUserCustomProfileChanged.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_profile', full_name='dialog.UpdateUserCustomProfileChanged.custom_profile', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4886,
  serialized_end=4985,
)


_UPDATEUSERSTATUSCHANGED = _descriptor.Descriptor(
  name='UpdateUserStatusChanged',
  full_name='dialog.UpdateUserStatusChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateUserStatusChanged.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='dialog.UpdateUserStatusChanged.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4987,
  serialized_end=5091,
)


_UPDATEUSEREXTCHANGED = _descriptor.Descriptor(
  name='UpdateUserExtChanged',
  full_name='dialog.UpdateUserExtChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateUserExtChanged.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ext', full_name='dialog.UpdateUserExtChanged.ext', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5093,
  serialized_end=5198,
)


_UPDATEUSERFULLEXTCHANGED = _descriptor.Descriptor(
  name='UpdateUserFullExtChanged',
  full_name='dialog.UpdateUserFullExtChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateUserFullExtChanged.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ext', full_name='dialog.UpdateUserFullExtChanged.ext', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5200,
  serialized_end=5309,
)


_REQUESTLOADFULLUSERS = _descriptor.Descriptor(
  name='RequestLoadFullUsers',
  full_name='dialog.RequestLoadFullUsers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_peers', full_name='dialog.RequestLoadFullUsers.user_peers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5311,
  serialized_end=5419,
)


_RESPONSELOADFULLUSERS = _descriptor.Descriptor(
  name='ResponseLoadFullUsers',
  full_name='dialog.ResponseLoadFullUsers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='full_users', full_name='dialog.ResponseLoadFullUsers.full_users', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5421,
  serialized_end=5513,
)

_CONTACTRECORD.fields_by_name['type'].enum_type = _CONTACTTYPE
_CONTACTRECORD.fields_by_name['type_spec'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CONTACTRECORD.fields_by_name['string_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CONTACTRECORD.fields_by_name['long_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CONTACTRECORD.fields_by_name['title'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CONTACTRECORD.fields_by_name['subtitle'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERSTATUS.fields_by_name['type'].enum_type = _USERSTATUSTYPE
_USERSTATUS.fields_by_name['text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERDATA_EXT.containing_type = _USERDATA
_USERDATA_EXT.oneofs_by_name['v'].fields.append(
  _USERDATA_EXT.fields_by_name['s'])
_USERDATA_EXT.fields_by_name['s'].containing_oneof = _USERDATA_EXT.oneofs_by_name['v']
_USERDATA_EXT.oneofs_by_name['v'].fields.append(
  _USERDATA_EXT.fields_by_name['b'])
_USERDATA_EXT.fields_by_name['b'].containing_oneof = _USERDATA_EXT.oneofs_by_name['v']
_USERDATA.fields_by_name['nick'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERDATA.fields_by_name['sex'].enum_type = _SEX
_USERDATA.fields_by_name['avatar'].message_type = media__and__files__pb2._AVATAR
_USERDATA.fields_by_name['is_bot'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERDATA.fields_by_name['status'].enum_type = _USERDATA_LIFECYCLE
_USERDATA.fields_by_name['user_status'].message_type = _USERSTATUS
_USERDATA.fields_by_name['exts'].message_type = _USERDATA_EXT
_USERDATA.fields_by_name['obsoleteClock'].message_type = definitions__pb2._DATACLOCK
_USERDATA.fields_by_name['about'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERDATA.fields_by_name['contact_info'].message_type = _CONTACTRECORD
_USERDATA.fields_by_name['bot_commands'].message_type = _BOTCOMMAND
_USERDATA.fields_by_name['custom_profile'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERDATA.fields_by_name['hint'].enum_type = _USERDATA_HINT
_USERDATA_LIFECYCLE.containing_type = _USERDATA
_USERDATA_HINT.containing_type = _USERDATA
_USER.fields_by_name['data'].message_type = _USERDATA
_USERPARTIALINFO.fields_by_name['nick'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERPARTIALINFO.fields_by_name['avatar'].message_type = media__and__files__pb2._AVATAR
_USERPROFILE.fields_by_name['user'].message_type = _USER
_USERPROFILE.fields_by_name['contact_info'].message_type = _CONTACTRECORD
_USERPROFILE.fields_by_name['about'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERPROFILE.fields_by_name['time_zone'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERPROFILE.fields_by_name['bot_commands'].message_type = _BOTCOMMAND
_USERPROFILE.fields_by_name['integration_token'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FULLUSER.fields_by_name['contact_info'].message_type = _CONTACTRECORD
_FULLUSER.fields_by_name['about'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FULLUSER.fields_by_name['time_zone'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FULLUSER.fields_by_name['bot_commands'].message_type = _BOTCOMMAND
_FULLUSER.fields_by_name['is_blocked'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_FULLUSER.fields_by_name['integration_token'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FULLUSER.fields_by_name['status'].message_type = _USERSTATUS
_BOTCOMMAND.fields_by_name['loc_key'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REQUESTLOADUSERDATA_CLAIM.fields_by_name['user_peer'].message_type = peers__pb2._PEER
_REQUESTLOADUSERDATA_CLAIM.fields_by_name['group_member'].message_type = peers__pb2._PEER
_REQUESTLOADUSERDATA_CLAIM.containing_type = _REQUESTLOADUSERDATA
_REQUESTLOADUSERDATA_CLAIM.oneofs_by_name['kind'].fields.append(
  _REQUESTLOADUSERDATA_CLAIM.fields_by_name['p2p'])
_REQUESTLOADUSERDATA_CLAIM.fields_by_name['p2p'].containing_oneof = _REQUESTLOADUSERDATA_CLAIM.oneofs_by_name['kind']
_REQUESTLOADUSERDATA_CLAIM.oneofs_by_name['kind'].fields.append(
  _REQUESTLOADUSERDATA_CLAIM.fields_by_name['group_member'])
_REQUESTLOADUSERDATA_CLAIM.fields_by_name['group_member'].containing_oneof = _REQUESTLOADUSERDATA_CLAIM.oneofs_by_name['kind']
_REQUESTLOADUSERDATA_CLAIM.oneofs_by_name['kind'].fields.append(
  _REQUESTLOADUSERDATA_CLAIM.fields_by_name['contact'])
_REQUESTLOADUSERDATA_CLAIM.fields_by_name['contact'].containing_oneof = _REQUESTLOADUSERDATA_CLAIM.oneofs_by_name['kind']
_REQUESTLOADUSERDATA.fields_by_name['claims'].message_type = _REQUESTLOADUSERDATA_CLAIM
_RESPONSELOADUSERDATA.fields_by_name['users'].message_type = _USER
_UPDATEUSER.fields_by_name['data'].message_type = _USERDATA
_UPDATEUSERAVATARCHANGED.fields_by_name['avatar'].message_type = media__and__files__pb2._AVATAR
_UPDATEUSERLOCALNAMECHANGED.fields_by_name['local_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEUSERCONTACTSCHANGED.fields_by_name['contact_records'].message_type = _CONTACTRECORD
_UPDATEUSERNICKCHANGED.fields_by_name['nickname'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEUSERABOUTCHANGED.fields_by_name['about'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEUSERTIMEZONECHANGED.fields_by_name['time_zone'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEUSERBOTCOMMANDSCHANGED.fields_by_name['commands'].message_type = _BOTCOMMAND
_UPDATEUSERSEXCHANGED.fields_by_name['sex'].enum_type = _SEX
_UPDATEUSERSTATUSCHANGED.fields_by_name['status'].message_type = _USERSTATUS
_UPDATEUSEREXTCHANGED.fields_by_name['ext'].message_type = miscellaneous__pb2._RECURSIVEMAPVALUE
_UPDATEUSERFULLEXTCHANGED.fields_by_name['ext'].message_type = miscellaneous__pb2._RECURSIVEMAPVALUE
_REQUESTLOADFULLUSERS.fields_by_name['user_peers'].message_type = peers__pb2._USEROUTPEER
_RESPONSELOADFULLUSERS.fields_by_name['full_users'].message_type = _FULLUSER
DESCRIPTOR.message_types_by_name['ContactRecord'] = _CONTACTRECORD
DESCRIPTOR.message_types_by_name['UserStatus'] = _USERSTATUS
DESCRIPTOR.message_types_by_name['UserData'] = _USERDATA
DESCRIPTOR.message_types_by_name['User'] = _USER
DESCRIPTOR.message_types_by_name['UserPartialInfo'] = _USERPARTIALINFO
DESCRIPTOR.message_types_by_name['UserProfile'] = _USERPROFILE
DESCRIPTOR.message_types_by_name['FullUser'] = _FULLUSER
DESCRIPTOR.message_types_by_name['BotCommand'] = _BOTCOMMAND
DESCRIPTOR.message_types_by_name['RequestEditUserLocalName'] = _REQUESTEDITUSERLOCALNAME
DESCRIPTOR.message_types_by_name['RequestLoadUserData'] = _REQUESTLOADUSERDATA
DESCRIPTOR.message_types_by_name['ResponseLoadUserData'] = _RESPONSELOADUSERDATA
DESCRIPTOR.message_types_by_name['UpdateUser'] = _UPDATEUSER
DESCRIPTOR.message_types_by_name['UpdateUserAvatarChanged'] = _UPDATEUSERAVATARCHANGED
DESCRIPTOR.message_types_by_name['UpdateUserNameChanged'] = _UPDATEUSERNAMECHANGED
DESCRIPTOR.message_types_by_name['UpdateUserLocalNameChanged'] = _UPDATEUSERLOCALNAMECHANGED
DESCRIPTOR.message_types_by_name['UpdateUserContactsChanged'] = _UPDATEUSERCONTACTSCHANGED
DESCRIPTOR.message_types_by_name['UpdateUserNickChanged'] = _UPDATEUSERNICKCHANGED
DESCRIPTOR.message_types_by_name['UpdateUserAboutChanged'] = _UPDATEUSERABOUTCHANGED
DESCRIPTOR.message_types_by_name['UpdateUserPreferredLanguagesChanged'] = _UPDATEUSERPREFERREDLANGUAGESCHANGED
DESCRIPTOR.message_types_by_name['UpdateUserTimeZoneChanged'] = _UPDATEUSERTIMEZONECHANGED
DESCRIPTOR.message_types_by_name['UpdateUserBotCommandsChanged'] = _UPDATEUSERBOTCOMMANDSCHANGED
DESCRIPTOR.message_types_by_name['UpdateUserSexChanged'] = _UPDATEUSERSEXCHANGED
DESCRIPTOR.message_types_by_name['UpdateUserCustomProfileChanged'] = _UPDATEUSERCUSTOMPROFILECHANGED
DESCRIPTOR.message_types_by_name['UpdateUserStatusChanged'] = _UPDATEUSERSTATUSCHANGED
DESCRIPTOR.message_types_by_name['UpdateUserExtChanged'] = _UPDATEUSEREXTCHANGED
DESCRIPTOR.message_types_by_name['UpdateUserFullExtChanged'] = _UPDATEUSERFULLEXTCHANGED
DESCRIPTOR.message_types_by_name['RequestLoadFullUsers'] = _REQUESTLOADFULLUSERS
DESCRIPTOR.message_types_by_name['ResponseLoadFullUsers'] = _RESPONSELOADFULLUSERS
DESCRIPTOR.enum_types_by_name['Sex'] = _SEX
DESCRIPTOR.enum_types_by_name['ContactType'] = _CONTACTTYPE
DESCRIPTOR.enum_types_by_name['UserStatusType'] = _USERSTATUSTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ContactRecord = _reflection.GeneratedProtocolMessageType('ContactRecord', (_message.Message,), {
  'DESCRIPTOR' : _CONTACTRECORD,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ContactRecord)
  })
_sym_db.RegisterMessage(ContactRecord)

UserStatus = _reflection.GeneratedProtocolMessageType('UserStatus', (_message.Message,), {
  'DESCRIPTOR' : _USERSTATUS,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UserStatus)
  })
_sym_db.RegisterMessage(UserStatus)

UserData = _reflection.GeneratedProtocolMessageType('UserData', (_message.Message,), {

  'Ext' : _reflection.GeneratedProtocolMessageType('Ext', (_message.Message,), {
    'DESCRIPTOR' : _USERDATA_EXT,
    '__module__' : 'users_pb2'
    # @@protoc_insertion_point(class_scope:dialog.UserData.Ext)
    })
  ,
  'DESCRIPTOR' : _USERDATA,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UserData)
  })
_sym_db.RegisterMessage(UserData)
_sym_db.RegisterMessage(UserData.Ext)

User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), {
  'DESCRIPTOR' : _USER,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.User)
  })
_sym_db.RegisterMessage(User)

UserPartialInfo = _reflection.GeneratedProtocolMessageType('UserPartialInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERPARTIALINFO,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UserPartialInfo)
  })
_sym_db.RegisterMessage(UserPartialInfo)

UserProfile = _reflection.GeneratedProtocolMessageType('UserProfile', (_message.Message,), {
  'DESCRIPTOR' : _USERPROFILE,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UserProfile)
  })
_sym_db.RegisterMessage(UserProfile)

FullUser = _reflection.GeneratedProtocolMessageType('FullUser', (_message.Message,), {
  'DESCRIPTOR' : _FULLUSER,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.FullUser)
  })
_sym_db.RegisterMessage(FullUser)

BotCommand = _reflection.GeneratedProtocolMessageType('BotCommand', (_message.Message,), {
  'DESCRIPTOR' : _BOTCOMMAND,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.BotCommand)
  })
_sym_db.RegisterMessage(BotCommand)

RequestEditUserLocalName = _reflection.GeneratedProtocolMessageType('RequestEditUserLocalName', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTEDITUSERLOCALNAME,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestEditUserLocalName)
  })
_sym_db.RegisterMessage(RequestEditUserLocalName)

RequestLoadUserData = _reflection.GeneratedProtocolMessageType('RequestLoadUserData', (_message.Message,), {

  'Claim' : _reflection.GeneratedProtocolMessageType('Claim', (_message.Message,), {
    'DESCRIPTOR' : _REQUESTLOADUSERDATA_CLAIM,
    '__module__' : 'users_pb2'
    # @@protoc_insertion_point(class_scope:dialog.RequestLoadUserData.Claim)
    })
  ,
  'DESCRIPTOR' : _REQUESTLOADUSERDATA,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLoadUserData)
  })
_sym_db.RegisterMessage(RequestLoadUserData)
_sym_db.RegisterMessage(RequestLoadUserData.Claim)

ResponseLoadUserData = _reflection.GeneratedProtocolMessageType('ResponseLoadUserData', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSELOADUSERDATA,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseLoadUserData)
  })
_sym_db.RegisterMessage(ResponseLoadUserData)

UpdateUser = _reflection.GeneratedProtocolMessageType('UpdateUser', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSER,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateUser)
  })
_sym_db.RegisterMessage(UpdateUser)

UpdateUserAvatarChanged = _reflection.GeneratedProtocolMessageType('UpdateUserAvatarChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERAVATARCHANGED,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateUserAvatarChanged)
  })
_sym_db.RegisterMessage(UpdateUserAvatarChanged)

UpdateUserNameChanged = _reflection.GeneratedProtocolMessageType('UpdateUserNameChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERNAMECHANGED,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateUserNameChanged)
  })
_sym_db.RegisterMessage(UpdateUserNameChanged)

UpdateUserLocalNameChanged = _reflection.GeneratedProtocolMessageType('UpdateUserLocalNameChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERLOCALNAMECHANGED,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateUserLocalNameChanged)
  })
_sym_db.RegisterMessage(UpdateUserLocalNameChanged)

UpdateUserContactsChanged = _reflection.GeneratedProtocolMessageType('UpdateUserContactsChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERCONTACTSCHANGED,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateUserContactsChanged)
  })
_sym_db.RegisterMessage(UpdateUserContactsChanged)

UpdateUserNickChanged = _reflection.GeneratedProtocolMessageType('UpdateUserNickChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERNICKCHANGED,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateUserNickChanged)
  })
_sym_db.RegisterMessage(UpdateUserNickChanged)

UpdateUserAboutChanged = _reflection.GeneratedProtocolMessageType('UpdateUserAboutChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERABOUTCHANGED,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateUserAboutChanged)
  })
_sym_db.RegisterMessage(UpdateUserAboutChanged)

UpdateUserPreferredLanguagesChanged = _reflection.GeneratedProtocolMessageType('UpdateUserPreferredLanguagesChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERPREFERREDLANGUAGESCHANGED,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateUserPreferredLanguagesChanged)
  })
_sym_db.RegisterMessage(UpdateUserPreferredLanguagesChanged)

UpdateUserTimeZoneChanged = _reflection.GeneratedProtocolMessageType('UpdateUserTimeZoneChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERTIMEZONECHANGED,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateUserTimeZoneChanged)
  })
_sym_db.RegisterMessage(UpdateUserTimeZoneChanged)

UpdateUserBotCommandsChanged = _reflection.GeneratedProtocolMessageType('UpdateUserBotCommandsChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERBOTCOMMANDSCHANGED,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateUserBotCommandsChanged)
  })
_sym_db.RegisterMessage(UpdateUserBotCommandsChanged)

UpdateUserSexChanged = _reflection.GeneratedProtocolMessageType('UpdateUserSexChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERSEXCHANGED,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateUserSexChanged)
  })
_sym_db.RegisterMessage(UpdateUserSexChanged)

UpdateUserCustomProfileChanged = _reflection.GeneratedProtocolMessageType('UpdateUserCustomProfileChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERCUSTOMPROFILECHANGED,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateUserCustomProfileChanged)
  })
_sym_db.RegisterMessage(UpdateUserCustomProfileChanged)

UpdateUserStatusChanged = _reflection.GeneratedProtocolMessageType('UpdateUserStatusChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERSTATUSCHANGED,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateUserStatusChanged)
  })
_sym_db.RegisterMessage(UpdateUserStatusChanged)

UpdateUserExtChanged = _reflection.GeneratedProtocolMessageType('UpdateUserExtChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSEREXTCHANGED,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateUserExtChanged)
  })
_sym_db.RegisterMessage(UpdateUserExtChanged)

UpdateUserFullExtChanged = _reflection.GeneratedProtocolMessageType('UpdateUserFullExtChanged', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERFULLEXTCHANGED,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateUserFullExtChanged)
  })
_sym_db.RegisterMessage(UpdateUserFullExtChanged)

RequestLoadFullUsers = _reflection.GeneratedProtocolMessageType('RequestLoadFullUsers', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTLOADFULLUSERS,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLoadFullUsers)
  })
_sym_db.RegisterMessage(RequestLoadFullUsers)

ResponseLoadFullUsers = _reflection.GeneratedProtocolMessageType('ResponseLoadFullUsers', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSELOADFULLUSERS,
  '__module__' : 'users_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseLoadFullUsers)
  })
_sym_db.RegisterMessage(ResponseLoadFullUsers)


DESCRIPTOR._options = None
_CONTACTRECORD.fields_by_name['type']._options = None
_CONTACTRECORD.fields_by_name['type_spec']._options = None
_CONTACTRECORD.fields_by_name['string_value']._options = None
_CONTACTRECORD.fields_by_name['long_value']._options = None
_CONTACTRECORD.fields_by_name['title']._options = None
_CONTACTRECORD.fields_by_name['subtitle']._options = None
_USERSTATUS.fields_by_name['type']._options = None
_USERSTATUS.fields_by_name['text']._options = None
_USERSTATUS.fields_by_name['clock']._options = None
_USERDATA.fields_by_name['name']._options = None
_USERDATA.fields_by_name['nick']._options = None
_USERDATA.fields_by_name['sex']._options = None
_USERDATA.fields_by_name['avatar']._options = None
_USERDATA.fields_by_name['is_bot']._options = None
_USERDATA.fields_by_name['status']._options = None
_USERDATA.fields_by_name['user_status']._options = None
_USERDATA.fields_by_name['time_zone']._options = None
_USERDATA.fields_by_name['exts']._options = None
_USERDATA.fields_by_name['obsoleteClock']._options = None
_USERDATA.fields_by_name['about']._options = None
_USERDATA.fields_by_name['contact_info']._options = None
_USERDATA.fields_by_name['bot_commands']._options = None
_USER.fields_by_name['id']._options = None
_USER.fields_by_name['access_hash']._options = None
_USERPARTIALINFO.fields_by_name['id']._options = None
_USERPARTIALINFO.fields_by_name['access_hash']._options = None
_USERPARTIALINFO.fields_by_name['clock']._options = None
_USERPARTIALINFO.fields_by_name['name']._options = None
_USERPARTIALINFO.fields_by_name['nick']._options = None
_USERPARTIALINFO.fields_by_name['avatar']._options = None
_USERPROFILE.fields_by_name['user']._options = None
_USERPROFILE.fields_by_name['contact_info']._options = None
_USERPROFILE.fields_by_name['about']._options = None
_USERPROFILE.fields_by_name['preferred_languages']._options = None
_USERPROFILE.fields_by_name['time_zone']._options = None
_USERPROFILE.fields_by_name['bot_commands']._options = None
_FULLUSER.fields_by_name['id']._options = None
_FULLUSER.fields_by_name['contact_info']._options = None
_FULLUSER.fields_by_name['about']._options = None
_FULLUSER.fields_by_name['preferred_languages']._options = None
_FULLUSER.fields_by_name['time_zone']._options = None
_FULLUSER.fields_by_name['bot_commands']._options = None
_FULLUSER.fields_by_name['is_blocked']._options = None
_FULLUSER.fields_by_name['status']._options = None
_BOTCOMMAND.fields_by_name['slash_command']._options = None
_BOTCOMMAND.fields_by_name['description']._options = None
_BOTCOMMAND.fields_by_name['loc_key']._options = None
_REQUESTEDITUSERLOCALNAME.fields_by_name['uid']._options = None
_REQUESTEDITUSERLOCALNAME.fields_by_name['access_hash']._options = None
_REQUESTEDITUSERLOCALNAME.fields_by_name['name']._options = None
_REQUESTEDITUSERLOCALNAME._options = None
_REQUESTLOADUSERDATA_CLAIM.fields_by_name['user_peer']._options = None
_REQUESTLOADUSERDATA_CLAIM.fields_by_name['p2p']._options = None
_REQUESTLOADUSERDATA_CLAIM.fields_by_name['group_member']._options = None
_REQUESTLOADUSERDATA_CLAIM.fields_by_name['contact']._options = None
_REQUESTLOADUSERDATA.fields_by_name['claims']._options = None
_REQUESTLOADUSERDATA._options = None
_RESPONSELOADUSERDATA.fields_by_name['users']._options = None
_RESPONSELOADUSERDATA._options = None
_UPDATEUSERAVATARCHANGED.fields_by_name['uid']._options = None
_UPDATEUSERAVATARCHANGED.fields_by_name['avatar']._options = None
_UPDATEUSERNAMECHANGED.fields_by_name['uid']._options = None
_UPDATEUSERNAMECHANGED.fields_by_name['name']._options = None
_UPDATEUSERLOCALNAMECHANGED.fields_by_name['uid']._options = None
_UPDATEUSERLOCALNAMECHANGED.fields_by_name['local_name']._options = None
_UPDATEUSERCONTACTSCHANGED.fields_by_name['uid']._options = None
_UPDATEUSERCONTACTSCHANGED.fields_by_name['contact_records']._options = None
_UPDATEUSERNICKCHANGED.fields_by_name['uid']._options = None
_UPDATEUSERNICKCHANGED.fields_by_name['nickname']._options = None
_UPDATEUSERABOUTCHANGED.fields_by_name['uid']._options = None
_UPDATEUSERABOUTCHANGED.fields_by_name['about']._options = None
_UPDATEUSERPREFERREDLANGUAGESCHANGED.fields_by_name['uid']._options = None
_UPDATEUSERPREFERREDLANGUAGESCHANGED.fields_by_name['preferred_languages']._options = None
_UPDATEUSERTIMEZONECHANGED.fields_by_name['uid']._options = None
_UPDATEUSERTIMEZONECHANGED.fields_by_name['time_zone']._options = None
_UPDATEUSERBOTCOMMANDSCHANGED.fields_by_name['uid']._options = None
_UPDATEUSERBOTCOMMANDSCHANGED.fields_by_name['commands']._options = None
_UPDATEUSERSEXCHANGED.fields_by_name['uid']._options = None
_UPDATEUSERSEXCHANGED.fields_by_name['sex']._options = None
_UPDATEUSERCUSTOMPROFILECHANGED.fields_by_name['uid']._options = None
_UPDATEUSERCUSTOMPROFILECHANGED.fields_by_name['custom_profile']._options = None
_UPDATEUSERSTATUSCHANGED.fields_by_name['uid']._options = None
_UPDATEUSERSTATUSCHANGED.fields_by_name['status']._options = None
_UPDATEUSEREXTCHANGED.fields_by_name['uid']._options = None
_UPDATEUSEREXTCHANGED.fields_by_name['ext']._options = None
_UPDATEUSERFULLEXTCHANGED.fields_by_name['uid']._options = None
_UPDATEUSERFULLEXTCHANGED.fields_by_name['ext']._options = None
_REQUESTLOADFULLUSERS.fields_by_name['user_peers']._options = None
_REQUESTLOADFULLUSERS._options = None
_RESPONSELOADFULLUSERS._options = None

_USERS = _descriptor.ServiceDescriptor(
  name='Users',
  full_name='dialog.Users',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=5888,
  serialized_end=6250,
  methods=[
  _descriptor.MethodDescriptor(
    name='EditUserLocalName',
    full_name='dialog.Users.EditUserLocalName',
    index=0,
    containing_service=None,
    input_type=_REQUESTEDITUSERLOCALNAME,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=b'\202\323\344\223\002%\" /v1/grpc/Users/EditUserLocalName:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LoadFullUsers',
    full_name='dialog.Users.LoadFullUsers',
    index=1,
    containing_service=None,
    input_type=_REQUESTLOADFULLUSERS,
    output_type=_RESPONSELOADFULLUSERS,
    serialized_options=b'\202\323\344\223\002!\"\034/v1/grpc/Users/LoadFullUsers:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LoadUserData',
    full_name='dialog.Users.LoadUserData',
    index=2,
    containing_service=None,
    input_type=_REQUESTLOADUSERDATA,
    output_type=_RESPONSELOADUSERDATA,
    serialized_options=b'\202\323\344\223\002 \"\033/v1/grpc/Users/LoadUserData:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_USERS)

DESCRIPTOR.services_by_name['Users'] = _USERS

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import media_and_files_pb2 as media__and__files__pb2


class MediaAndFilesStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetFileUrl = channel.unary_unary(
                '/dialog.MediaAndFiles/GetFileUrl',
                request_serializer=media__and__files__pb2.RequestGetFileUrl.SerializeToString,
                response_deserializer=media__and__files__pb2.ResponseGetFileUrl.FromString,
                )
        self.GetFileUrls = channel.unary_unary(
                '/dialog.MediaAndFiles/GetFileUrls',
                request_serializer=media__and__files__pb2.RequestGetFileUrls.SerializeToString,
                response_deserializer=media__and__files__pb2.ResponseGetFileUrls.FromString,
                )
        self.GetFileUrlBuilder = channel.unary_unary(
                '/dialog.MediaAndFiles/GetFileUrlBuilder',
                request_serializer=media__and__files__pb2.RequestGetFileUrlBuilder.SerializeToString,
                response_deserializer=media__and__files__pb2.ResponseGetFileUrlBuilder.FromString,
                )
        self.GetFileUploadUrl = channel.unary_unary(
                '/dialog.MediaAndFiles/GetFileUploadUrl',
                request_serializer=media__and__files__pb2.RequestGetFileUploadUrl.SerializeToString,
                response_deserializer=media__and__files__pb2.ResponseGetFileUploadUrl.FromString,
                )
        self.CommitFileUpload = channel.unary_unary(
                '/dialog.MediaAndFiles/CommitFileUpload',
                request_serializer=media__and__files__pb2.RequestCommitFileUpload.SerializeToString,
                response_deserializer=media__and__files__pb2.ResponseCommitFileUpload.FromString,
                )
        self.GetFileUploadPartUrl = channel.unary_unary(
                '/dialog.MediaAndFiles/GetFileUploadPartUrl',
                request_serializer=media__and__files__pb2.RequestGetFileUploadPartUrl.SerializeToString,
                response_deserializer=media__and__files__pb2.ResponseGetFileUploadPartUrl.FromString,
                )


class MediaAndFilesServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetFileUrl(self, request, context):
        """/ Get link to file for downloading
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFileUrls(self, request, context):
        """/ Get link to files for downloading
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFileUrlBuilder(self, request, context):
        """/ Create builder for file url
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFileUploadUrl(self, request, context):
        """/ Get url for uploading
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CommitFileUpload(self, request, context):
        """/ Finish uploading a file
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFileUploadPartUrl(self, request, context):
        """/ Get url for uploading chunk of file
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MediaAndFilesServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetFileUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFileUrl,
                    request_deserializer=media__and__files__pb2.RequestGetFileUrl.FromString,
                    response_serializer=media__and__files__pb2.ResponseGetFileUrl.SerializeToString,
            ),
            'GetFileUrls': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFileUrls,
                    request_deserializer=media__and__files__pb2.RequestGetFileUrls.FromString,
                    response_serializer=media__and__files__pb2.ResponseGetFileUrls.SerializeToString,
            ),
            'GetFileUrlBuilder': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFileUrlBuilder,
                    request_deserializer=media__and__files__pb2.RequestGetFileUrlBuilder.FromString,
                    response_serializer=media__and__files__pb2.ResponseGetFileUrlBuilder.SerializeToString,
            ),
            'GetFileUploadUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFileUploadUrl,
                    request_deserializer=media__and__files__pb2.RequestGetFileUploadUrl.FromString,
                    response_serializer=media__and__files__pb2.ResponseGetFileUploadUrl.SerializeToString,
            ),
            'CommitFileUpload': grpc.unary_unary_rpc_method_handler(
                    servicer.CommitFileUpload,
                    request_deserializer=media__and__files__pb2.RequestCommitFileUpload.FromString,
                    response_serializer=media__and__files__pb2.ResponseCommitFileUpload.SerializeToString,
            ),
            'GetFileUploadPartUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFileUploadPartUrl,
                    request_deserializer=media__and__files__pb2.RequestGetFileUploadPartUrl.FromString,
                    response_serializer=media__and__files__pb2.ResponseGetFileUploadPartUrl.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.MediaAndFiles', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MediaAndFiles(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetFileUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.MediaAndFiles/GetFileUrl',
            media__and__files__pb2.RequestGetFileUrl.SerializeToString,
            media__and__files__pb2.ResponseGetFileUrl.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFileUrls(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.MediaAndFiles/GetFileUrls',
            media__and__files__pb2.RequestGetFileUrls.SerializeToString,
            media__and__files__pb2.ResponseGetFileUrls.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFileUrlBuilder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.MediaAndFiles/GetFileUrlBuilder',
            media__and__files__pb2.RequestGetFileUrlBuilder.SerializeToString,
            media__and__files__pb2.ResponseGetFileUrlBuilder.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFileUploadUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.MediaAndFiles/GetFileUploadUrl',
            media__and__files__pb2.RequestGetFileUploadUrl.SerializeToString,
            media__and__files__pb2.ResponseGetFileUploadUrl.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CommitFileUpload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.MediaAndFiles/CommitFileUpload',
            media__and__files__pb2.RequestCommitFileUpload.SerializeToString,
            media__and__files__pb2.ResponseCommitFileUpload.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFileUploadPartUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.MediaAndFiles/GetFileUploadPartUrl',
            media__and__files__pb2.RequestGetFileUploadPartUrl.SerializeToString,
            media__and__files__pb2.ResponseGetFileUploadPartUrl.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
